FleatherCustomClipboardGetData typedef
FleatherCustomClipboardGetData =
Future<FleatherClipboardData?> Function()
Used by FleatherCustomClipboardManager to get clipboard data.
Null should be returned in case clipboard has no data or data is invalid and both FleatherClipboardData.plainText and FleatherClipboardData.delta are null.
Implementation
typedef FleatherCustomClipboardGetData = Future<FleatherClipboardData?>
Function();