FleatherLocalizationsFa class

The translations for Persian (fa).

Inheritance

Constructors

FleatherLocalizationsFa([String locale = 'fa'])

Properties

addLinkDialogApply → String
Label for the confirmation button in the link dialog
no setteroverride
Label for the input decoration of the link text field in the add link dialog
no setteroverride
backgroundColorNoColor → String
Assign no background color to the text
no setteroverride
foregroundColorAutomatic → String
Automatically assign a foreground color to the text
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
headingLevel1 → String
A level 1 heading text style
no setteroverride
headingLevel2 → String
A level 2 heading text style
no setteroverride
headingLevel3 → String
A level 3 heading text style
no setteroverride
headingLevel4 → String
A level 4 heading text style
no setteroverride
headingLevel5 → String
A level 5 heading text style
no setteroverride
headingLevel6 → String
A level 6 heading text style
no setteroverride
headingNormal → String
A normal heading text style
no setteroverride
linkDialogCopy → String
Copy the link
no setteroverride
linkDialogOpen → String
Open the link
no setteroverride
linkDialogRemove → String
Remove the link
no setteroverride
localeName → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited